//
//  BMICalculator.swift
//  BMI
//
//  Created by Park on 9/6/15.
//  Copyright © 2015 Park. All rights reserved.
//

import Foundation

enum Gender {
    case Female
    case Male
}

enum BMI {
    case Underweight
    case Normal
    case Overweight
    case Obesity
}

enum Activity {
    case Low
    case Medium
    case High
}

class BMICalculator {
    var height: Float = 165.0
    var weight: Float = 55.0
    var age: Int = 30
    var gender = Gender.Female
    var activity = Activity.Medium

    init() {
        height = 165.0
        weight = 55.0
        age = 30
        gender = Gender.Female
        activity = Activity.Medium
    }
    
    func calculateStandardWeight() -> Float {
        if (self.gender == Gender.Male) {
            return height * height * 22 * 0.0001
        }
        return height * height * 21 * 0.0001
    }
    
    func calculateBMI() -> BMI {
        let bmi = weight / (height * 0.01) / (height * 0.01)
        print(bmi)
        switch bmi {
        case 0.0 ..< 20.0:
            return BMI.Underweight
        case 20.0 ..< 24.0:
            return BMI.Normal
        case 24.0 ..< 30:
            return BMI.Overweight
        default:
            return BMI.Obesity
        }
    }

    // Herris Benedict Equation
    func calculateDailyCaloryIntake() -> Float {
        var activityCalory : Float = 1.0
        switch self.activity {
        case .Low:
            activityCalory = 1.3
        case .Medium:
            activityCalory = 1.5
        case .High:
            activityCalory = 1.75
        }

        if (self.gender == Gender.Male) {
            return (66.47 + (13.75 * self.weight) + (5.0 * self.height) - (6.76 * Float(self.age))) * activityCalory
        }
        return (655.1 + (9.05 * self.weight) + (1.85 * self.height) - (4.68 * Float(self.age))) * activityCalory
    }
}