//
//  ViewController.swift
//  BMI
//
//  Created by Park on 9/6/15.
//  Copyright © 2015 Park. All rights reserved.
//

import UIKit

extension String {
    func toFloat() -> Float {
        if let unwrappedNum = Float(self) {
            return unwrappedNum
        }
        else {
            print("Error converting \"" + self + "\" to Float")
            return 0.0
        }
    }
    func toInt() -> Int {
        if let unwrappedNum = Int(self) {
            return unwrappedNum
        }
        else {
            print("Error converting \"" + self + "\" to Int")
            return 0
        }
    }
}

class ViewController: UIViewController, UIPickerViewDelegate, UIPickerViewDataSource {

    @IBOutlet weak var heightTextField: UITextField!
    
    @IBOutlet weak var weightTextField: UITextField!
    
    @IBOutlet weak var ageTextField: UITextField!
    
    @IBOutlet weak var genderSelector: UISegmentedControl!
    
    @IBOutlet weak var activityPicker: UIPickerView!
    
    @IBOutlet weak var bmiTextField: UITextField!

    @IBOutlet weak var swTextField: UITextField!

    @IBOutlet weak var diTextField: UITextField!

    override var description: String {
        return "Standard Weight: \(sw), BMI: \(bmi), DailyIntake: \(dailyIntake)"
    }
    
    var calculator = BMICalculator()
    var sw: Float = 50.0
    var bmi: BMI = BMI.Normal
    var age: Int = 35
    var activity: Activity = Activity.Low
    var activityPickerElements = ["Low", "Medium", "High"]
    var dailyIntake: Float = 1500.0
    
    func selectGender() -> Gender {
        if (genderSelector.selectedSegmentIndex == 0) {
            return Gender.Male
        }
        return Gender.Female
    }

    @IBAction func calculateStandardWeightAndBMI(sender: AnyObject) {
        calculator.height = heightTextField.text!.toFloat()
        calculator.weight = weightTextField.text!.toFloat()
        calculator.gender = selectGender()
        calculator.age = ageTextField.text!.toInt()
        calculator.activity = activity
        NSLog("height=\(calculator.height)")
        NSLog("weight=\(calculator.weight)")
        NSLog("gender=\(calculator.gender)")
        NSLog("age=\(calculator.age)")
        NSLog("activity=\(calculator.activity)")
        sw = calculator.calculateStandardWeight()
        bmi = calculator.calculateBMI()
        dailyIntake = calculator.calculateDailyCaloryIntake()
        //bmiTextField.text = String.localizedStringWithFormat("Standard Weight: \(sw), BMI: \(bmi)", sw, String(bmi))
        NSLog("bmi=\(self.description)")
        bmiTextField.text = "\(bmi)"
        swTextField.text = "\(sw)"
        diTextField.text = "\(dailyIntake)"
    }
    
    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        heightTextField.text = "\(calculator.height)"
        weightTextField.text = "\(calculator.weight)"
        genderSelector.selectedSegmentIndex = 1 // Female
        ageTextField.text = "\(calculator.age)"

        // connect picker delegate & dataSource
        activityPicker.delegate = self
        activityPicker.dataSource = self
        // set the default value of picker
        activityPicker.selectRow(1, inComponent: 0, animated: true) // Medium
        
        sw = calculator.calculateStandardWeight()
        bmi = calculator.calculateBMI()
        bmiTextField.text = "\(bmi)"
        swTextField.text = "\(sw)"
        diTextField.text = "\(dailyIntake)"
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // the number of columns in picker elements
    func numberOfComponentsInPickerView(pickerView: UIPickerView) -> Int {
        return 1
    }
    // the number of rows in picker elements
    func pickerView(pickerView: UIPickerView, numberOfRowsInComponent component: Int) -> Int {
        return activityPickerElements.count
    }
    // the element to return for row and column that's being passed in
    func pickerView(pickerView: UIPickerView, titleForRow row: Int, forComponent component: Int) -> String? {
        return activityPickerElements[row]
    }
    // when selected UIPickerView row, call this delegate
    func pickerView(pickerView: UIPickerView, didSelectRow row: Int, inComponent component: Int) {
        if (row == 0) {
            activity = Activity.Low
        }
        else if (row == 1) {
            activity = Activity.Medium
        }
        else if (row == 2) {
            activity = Activity.High
        }
    }
}

